pub enum DiagnosticsEmitterError {
NoDataspace,
}Expand description
Errors that can occur when creating a DiagnosticsEmitter.
Variants
NoDataspace
No dataspace was available in the current context.
An emitter can only be created within a running supervision tree, where an ambient dataspace is established. This indicates that creation was attempted outside of one.