pub struct DiagnosticCollector { /* private fields */ }Expand description
A named, on-demand producer of diagnostic artifact bytes.
A collector pairs an artifact name with a synchronous closure that produces the artifact’s bytes when
invoked. Collectors are registered through a DiagnosticsEmitter and gathered on
demand by whichever subsystem is responsible for assembling diagnostic artifacts.
The artifact name is suitable, but not guaranteed, to be used as a filename.
Implementations
Sourceimpl DiagnosticCollector
impl DiagnosticCollector
Sourcepub fn new<T>(
artifact_name: impl Into<String>,
collect_fn: impl Fn() -> T + Send + Sync + 'static,
) -> Self
pub fn new<T>( artifact_name: impl Into<String>, collect_fn: impl Fn() -> T + Send + Sync + 'static, ) -> Self
Creates a new collector with the given artifact name and collection closure.
collect_fn runs synchronously and must return promptly, as it can delay the collection of artifacts for the
whole system.
Sourcepub fn artifact_name(&self) -> &str
pub fn artifact_name(&self) -> &str
Returns the artifact name.