pub struct DiagnosticHandle { /* private fields */ }Expand description
A handle for exposing diagnostics from a component.
Components assert a handle where artifact name is suitable, but not guaranteed, to be used a filename
Example:
ⓘ
DataspaceRegistry::try_current()?
.assert(
DiagnosticHandle::new("my_artifact.json", move || {
serde_json::to_vec(&my_state).unwrap_or_default()
}),
"diag-my-component",
);Implementations
Sourceimpl DiagnosticHandle
impl DiagnosticHandle
Sourcepub fn new(
artifact_name: impl Into<String>,
collect_fn: impl Fn() -> Vec<u8> + Send + Sync + 'static,
) -> Self
pub fn new( artifact_name: impl Into<String>, collect_fn: impl Fn() -> Vec<u8> + Send + Sync + 'static, ) -> Self
Creates a new handle with the given artifact name and collection closure.
collect_fn must run synchronously and reasonably fast to produce artifact bytes
as it can delay entire diagnostic response
Sourcepub fn artifact_name(&self) -> &str
pub fn artifact_name(&self) -> &str
Returns the artifact name.